==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ru.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Настройки обновлены.",
"Activity" => "Журнал",
"A file or folder has been <strong>shared</strong>" => "Файл или папка был(а) <strong> опубликована </strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Файл или папка был(а) <strong> создан(а) </strong> в опубликованной папке",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Файл или папка был(а) <strong> изменен(а) </strong> в опубликованной папке",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Файл или папка был(а) <strong> удален/а </strong> в опубликованной папке",
"You created %1\$s" => "Вы создали %1\$s",
"%2\$s created %1\$s" => "%2\$s создано %1\$s",
"You changed %1\$s" => "Вы изменили %1\$s",
"%2\$s changed %1\$s" => "%2\$s изменено %1\$s",
"You deleted %1\$s" => "Вы удалили %1\$s",
"%2\$s deleted %1\$s" => "%2\$s удалено %1\$s",
"You shared %1\$s with %2\$s" => "Вы поделились %1\$s с %2\$s",
"You shared %1\$s with group %2\$s" => "Вы поделились %1\$s с группой %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s поделился %1\$s с вами",
"Activity notification" => "Уведомление об активности",
"All Activities" => "Все действия",
"Activities by you" => "Ваши действия",
"Activities by others" => "Действия других пользователей",
"Shares" => "Общие файлы",
"Files" => "Файлы",
"%s and %s" => "%s и %s",
", " => ",",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s и <strong class=\"tooltip\" title=\"%s\">%n ещё</strong>","%s и <strong class=\"tooltip\" title=\"%s\">%n ещё</strong>","%s и <strong class=\"tooltip\" title=\"%s\">%n ещё</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s и %n ещё","%s и %n ещё","%s и %n ещё"),
"Hello %s," => "Привет %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Вы получили это электронное сообщение, потому что за последний час произошли следующие изменения на %s",
"You are receiving this email because in the last day the following things happened at %s" => "Вы получили это электронное сообщение, потому что за последний день произошли следующие изменения на %s",
"You are receiving this email because in the last week the following things happened at %s" => "Вы получили это электронное сообщение, потому что за последнюю неделю произошли следующие изменения на %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Здесь будет виден список событий, когда вы начнете использовать %s.",
"No more events to load" => "Больше нет пунктов для загрузки",
"Enable RSS feed" => "Включить RSS ленту",
"Notifications" => "Уведомления",
"Mail" => "Почта",
"Stream" => "Поток",
"You need to set up your email address before you can receive notification emails." => "Вы должны настроить свой e-mail для получения уведомлений",
"Send emails:" => "Отправить электронные сообщения:",
"Hourly" => "Ежечасно",
"Daily" => "Ежедневно",
"Weekly" => "Еженедельно",
"Activity feed" => "Лента действий",
"Personal activity feed for %s" => "Лента действий - %s"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ru.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Настройки обновлены.",
"Activity" => "Журнал",
"A file or folder has been <strong>shared</strong>" => "Файл или папка был(а) <strong> опубликована </strong>",
"A new file or folder has been <strong>created</strong>" => "<strong>Создан</strong> новый файл или папка",
"A file or folder has been <strong>changed</strong>" => "<strong>Изменен</strong> файл или папка",
"A file or folder has been <strong>deleted</strong>" => "<strong>Удален</strong> файл или папка",
"You created %1\$s" => "Вы создали %1\$s",
"%2\$s created %1\$s" => "%2\$s создано %1\$s",
"You changed %1\$s" => "Вы изменили %1\$s",
"%2\$s changed %1\$s" => "%2\$s изменено %1\$s",
"You deleted %1\$s" => "Вы удалили %1\$s",
"%2\$s deleted %1\$s" => "%2\$s удалено %1\$s",
"You shared %1\$s with %2\$s" => "Вы поделились %1\$s с %2\$s",
"You shared %1\$s with group %2\$s" => "Вы поделились %1\$s с группой %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s поделился %1\$s с вами",
"You shared %1\$s via link" => "Вы опубликовали %1\$s по ссылке",
"Activity notification" => "Уведомление об активности",
"All Activities" => "Все действия",
"Activities by you" => "Ваши действия",
"Activities by others" => "Действия других пользователей",
"Shares" => "Общие файлы",
"Files" => "Файлы",
"%s and %s" => "%s и %s",
", " => ",",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s и <strong class=\"tooltip\" title=\"%s\">%n ещё</strong>","%s и <strong class=\"tooltip\" title=\"%s\">%n ещё</strong>","%s и <strong class=\"tooltip\" title=\"%s\">%n ещё</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s и %n ещё","%s и %n ещё","%s и %n ещё"),
"Hello %s," => "Привет %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Вы получили это электронное сообщение, потому что за последний час произошли следующие изменения на %s",
"You are receiving this email because in the last day the following things happened at %s" => "Вы получили это электронное сообщение, потому что за последний день произошли следующие изменения на %s",
"You are receiving this email because in the last week the following things happened at %s" => "Вы получили это электронное сообщение, потому что за последнюю неделю произошли следующие изменения на %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Здесь будет виден список событий, когда вы начнете использовать %s.",
"No more events to load" => "Больше нет пунктов для загрузки",
"Enable RSS feed" => "Включить RSS ленту",
"Notifications" => "Уведомления",
"Mail" => "Почта",
"Stream" => "Поток",
"Notify about my own actions" => "Уведомлять о моей активности",
"You need to set up your email address before you can receive notification emails." => "Вы должны настроить свой e-mail для получения уведомлений",
"Send emails:" => "Отправить электронные сообщения:",
"Hourly" => "Ежечасно",
"Daily" => "Ежедневно",
"Weekly" => "Еженедельно",
"Activity feed" => "Лента действий",
"Personal activity feed for %s" => "Лента действий - %s"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
